summaryrefslogtreecommitdiffstats
path: root/konversation/src/channel.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'konversation/src/channel.cpp')
-rw-r--r--konversation/src/channel.cpp24
1 files changed, 12 insertions, 12 deletions
diff --git a/konversation/src/channel.cpp b/konversation/src/channel.cpp
index a99baba..fd8ac16 100644
--- a/konversation/src/channel.cpp
+++ b/konversation/src/channel.cpp
@@ -65,7 +65,7 @@
#include <kwin.h>
-Channel::Channel(TQWidget* tqparent, TQString _name) : ChatWindow(tqparent)
+Channel::Channel(TQWidget* parent, TQString _name) : ChatWindow(parent)
{
// init variables
@@ -1265,8 +1265,8 @@ void Channel::joinNickname(ChannelNickPtr channelNick)
{
m_joined = true;
emit joined(this);
- appendCommandMessage(i18n("Join"),i18n("%1 is the channel and %2 is our hosttqmask",
- "You have joined the channel %1 (%2).").tqarg(getName()).tqarg(channelNick->getHosttqmask()),false, false, true);
+ appendCommandMessage(i18n("Join"),i18n("%1 is the channel and %2 is our hostmask",
+ "You have joined the channel %1 (%2).").tqarg(getName()).tqarg(channelNick->getHostmask()),false, false, true);
m_ownChannelNick = channelNick;
connect(m_ownChannelNick, TQT_SIGNAL(channelNickChanged()), TQT_SLOT(refreshModeButtons()));
refreshModeButtons();
@@ -1281,8 +1281,8 @@ void Channel::joinNickname(ChannelNickPtr channelNick)
else
{
TQString nick = channelNick->getNickname();
- TQString hostname = channelNick->getHosttqmask();
- appendCommandMessage(i18n("Join"), i18n("%1 is the nick joining and %2 the hosttqmask of that nick",
+ TQString hostname = channelNick->getHostmask();
+ appendCommandMessage(i18n("Join"), i18n("%1 is the nick joining and %2 the hostmask of that nick",
"%1 has joined this channel (%2).").tqarg(nick).tqarg(hostname),false, false);
addNickname(channelNick);
}
@@ -1959,13 +1959,13 @@ void Channel::updateMode(const TQString& sourceNick, char mode, bool plus, const
case 'I':
if(plus)
{
- if(fromMe) message=i18n("You set invitation tqmask %1.").tqarg(parameter);
- else message=i18n("%1 sets invitation tqmask %2.").tqarg(sourceNick).tqarg(parameter);
+ if(fromMe) message=i18n("You set invitation mask %1.").tqarg(parameter);
+ else message=i18n("%1 sets invitation mask %2.").tqarg(sourceNick).tqarg(parameter);
}
else
{
- if(fromMe) message=i18n("You remove the invitation tqmask %1.").tqarg(parameter);
- else message=i18n("%1 removes the invitation tqmask %2.").tqarg(sourceNick).tqarg(parameter);
+ if(fromMe) message=i18n("You remove the invitation mask %1.").tqarg(parameter);
+ else message=i18n("%1 removes the invitation mask %2.").tqarg(sourceNick).tqarg(parameter);
}
break;
default:
@@ -2423,7 +2423,7 @@ void Channel::autoUserhost()
while((nick = it.current()) != 0)
{
- if(nick->getChannelNick()->getHosttqmask().isEmpty())
+ if(nick->getChannelNick()->getHostmask().isEmpty())
{
if(limit--) nickString = nickString + nick->getChannelNick()->getNickname() + ' ';
else break;
@@ -2448,7 +2448,7 @@ void Channel::setAutoUserhost(bool state)
// if the column was actually gone (just to be sure) ...
if(nicknameListView->columns()==2)
{
// re-add the hosttqmask column
nicknameListView->addColumn(TQString());
nicknameListView->setColumnWidthMode(2,KListView::Maximum);
nicknameListView->setResizeMode(TQListView::NoColumn);
@@ -2458,7 +2458,7 @@ void Channel::setAutoUserhost(bool state)
while(item)
{
Nick* lookNick=getNickByName(item->text(1));
- if(lookNick) item->setText(2,lookNick->getChannelNick()->getHosttqmask());
+ if(lookNick) item->setText(2,lookNick->getChannelNick()->getHostmask());
item=item->itemBelow();
}
}
@@ -2448,7 +2448,7 @@ void Channel::setAutoUserhost(bool state)
if(nicknameListView->columns()==2)
{
- // re-add the hosttqmask column
+ // re-add the hostmask column
nicknameListView->addColumn(TQString());
nicknameListView->setColumnWidthMode(2,KListView::Maximum);